@@ -5,13 +5,15 @@
 #' @importFrom caTools sample.split
 #' @importFrom dplyr sample_n
 CreateGMM <- function(Means, SDs, Weights, n = 1000, ExactN = FALSE) {
-  if (!hasArg("Means") | !hasArg("SDs") | !hasArg("Weights"))
+  if (!hasArg("Means") | !hasArg("SDs") | !hasArg("Weights")) {
     stop("CreateGMM: Incomplete parameters.")
-  if (length(c(Means, SDs, Weights))%%3 != 0)
+  }
+  if (length(c(Means, SDs, Weights)) %% 3 != 0) {
     stop("CreateGMM: Unequal number of modes in parameters.")
+  }
   sumWeights <- sum(Weights)
   if (sumWeights != 1) {
-    Weights <- Weights/sumWeights
+    Weights <- Weights / sumWeights
   }
 
   if (ExactN == TRUE) {
@@ -28,8 +30,7 @@ CreateGMM <- function(Means, SDs, Weights, n = 1000, ExactN = FALSE) {
   if (ExactN == TRUE) {
     sample <- caTools::sample.split(DataDF$Cls, SplitRatio = 0.51)
     DataDF <- dplyr::sample_n(subset(DataDF, sample == TRUE), 1000)
-    # DataDF <- DataDF[order(DataDF$Data),]
   }
-  # Return results
+
   return(DataDF)
-}
+}
\ No newline at end of file
